# Nisaba 0.3.2

A tool for multi-modal annotation

## Most Recent Update

### v.0.3.2

+ Improved Taxonomy Editor Functions

[Full Change Log](https://github.com/mhbeals/nisaba/blob/master/changelog.md) and [Development Roadmap](https://github.com/mhbeals/nisaba/blob/master/roadmap.md)

## Easy (PIP) Installation:

*Nisaba* is now available through [PyPi](https://pypi.org/project/nisaba/).
To install using pip, simply run the following command from your terminal:

```
pip install nisaba
```

After installation, run *Nisaba* using the command:

```
nisaba
```

## Contributing

If you wish to contribute to the development of *Nisaba*, clone and run from the source code using the following commands from your terminal:

```
git clone https://github.com/mhbeals/nisaba
cd nisaba
virtualenv .
source bin/activate
pip install -r requirements.txt
```

To run, use

```
cd nisaba
python __main__.py
```

or simply:

```
python -m nisaba
```


## Development History
*Nisaba* was conceived by [M. H. Beals](https://github.com/mhbeals) (Loughborough University) and [Olivia Mitchell](https://www.lboro.ac.uk/departments/phir/staff/olivia-mitchell/) (Loughborough University) as part of her PhD project (2017-present).

Initial development of the software (v.0.1.0) was undertaken by [M. H. Beals](https://github.com/mhbeals) in 2018-2019.

The project is now being developed by [M. H. Beals](https://github.com/mhbeals) and [Albert Meroño Peñuela](https://github.com/albertmeronyo) (Vrije Universiteit Amsterdam). If you would like to contribute, please contact [M. H. Beals](https://github.com/mhbeals) (or submit a pull request!)
